@@ -7,4 +7,4 @@ DEFAULT_CONFIG_FILE = os.path.join(DEFAULT_CONFIG_DIR, "config")
 DEFAULT_CREDENTIALS_FILE = os.path.join(DEFAULT_CONFIG_DIR, "credentials")
 DEFAULT_PROFILE = "default"
 DEFAULT_GLOBAL_ENDPOINT = "production"
-DEFAULT_RESIDENCY = "us"
+DEFAULT_RESIDENCY = "default"
